@@ -6,7 +6,8 @@ from datetime import datetime
 from processor.logging.log_handler import getlogger
 from processor.helper.file.file_utils import exists_file
 from processor.helper.config.rundata_utils import get_from_currentdata, put_in_currentdata
-from processor.helper.httpapi.http_utils import http_post_request, http_get_request, http_put_request
+from processor.helper.httpapi.http_utils import http_post_request, http_get_request,\
+    http_put_request, http_delete_request
 from processor.helper.json.json_utils import get_field_value, json_from_file, collectiontypes, STRUCTURE
 from processor.helper.config.config_utils import get_test_json_dir, config_value
 from processor.database.database import DATABASE, DBNAME, sort_field, get_documents
@@ -219,6 +220,35 @@ def get_keyvault_secret(keyvault, secret_key, vaulttoken):
         logger.info("Get Id returned invalid status: %s", status)
     return data
 
+
+def get_all_secrets(keyvault, vaulttoken):
+    hdrs = {
+        'Authorization': 'Bearer %s' % vaulttoken
+    }
+    logger.info('Get Id REST API invoked!')
+    urlstr = 'https://%s.vault.azure.net/secrets?api-version=7.0'
+    url = urlstr % (keyvault)
+    keys_response = []
+    keys = []
+    while url != None:
+        status, data = http_get_request(url, hdrs)
+        if status and isinstance(status, int) and status == 200:
+            logger.debug('Data: %s', data)
+            values = data.get("value", [])
+            url = data.get("nextLink",None)
+            keys_response.extend(values)
+        else:
+            put_in_currentdata('errors', data)
+            url = None
+            logger.info("Get Id returned invalid status: %s", status)
+    for each_key in keys_response:
+        key_url = each_key.get("id",None)
+        if key_url:
+            secret_key = key_url.split("secrets/",1)[1].split("/")[0]
+            keys.append(secret_key)
+    return keys
+
+
 def set_keyvault_secret(keyvault, vaulttoken, secret_key, value):
 
     hdrs = {
@@ -240,3 +270,22 @@ def set_keyvault_secret(keyvault, vaulttoken, secret_key, value):
         put_in_currentdata('errors', data)
         logger.info("Set Id returned invalid status: %s", status)
         return False
+
+
+def delete_keyvault_secret(keyvault, secret_key, vaulttoken):
+    hdrs = {
+        'Authorization': 'Bearer %s' % vaulttoken
+    }
+    success = False
+    logger.info('Delete Id REST API invoked!')
+    urlstr = 'https://%s.vault.azure.net/secrets/%s?api-version=7.0'
+    url = urlstr % (keyvault, secret_key)
+    status, data = http_delete_request(url, headers=hdrs)
+    logger.info('Delete Id status: %s', status)
+    if status and isinstance(status, int) and status == 200:
+        logger.debug('Data: %s', data)
+        success = True
+    else:
+        put_in_currentdata('errors', data)
+        logger.info("Get Id returned invalid status: %s", status)
+    return success
\ No newline at end of file
